use actix_web::{App, HttpServer, web::Data};
use dotenvy::dotenv;
use tracing::Level;
use tracing_subscriber::FmtSubscriber;

mod access;
mod config;
mod handlers;

#[actix_web::main]
async fn main() -> std::io::Result<()> {
    let subscriber = FmtSubscriber::builder()
        .with_max_level(Level::TRACE)
        .finish();

    tracing::subscriber::set_global_default(subscriber).expect("Could not initialize logging.");

    dotenv().expect("Could not load .env file.");

    HttpServer::new(|| {
        let config = config::load_config();
        App::new()
            .app_data(Data::new(config))
            .wrap(actix_web::middleware::Logger::default())
            .service(handlers::get_cache_item)
            .service(handlers::put_cache_item)
    })
    .bind(("127.0.0.1", 8080))?
    .bind(("::1", 8080))?
    .run()
    .await
}
